@@ -1,35 +1,35 @@
-from pglet.control import Control
-from pglet.page import Page
-from pglet.stack import Stack
-from pglet.text import Text
-from pglet.textbox import Textbox
-from pglet.checkbox import Checkbox
-from pglet.progress import Progress
+from pglet.barchart import BarChart
 from pglet.button import Button
+from pglet.callout import Callout
+from pglet.checkbox import Checkbox
+from pglet.choicegroup import ChoiceGroup
+from pglet.control import Control
+from pglet.datepicker import DatePicker
+from pglet.dialog import Dialog
 from pglet.dropdown import Dropdown
+from pglet.grid import Column, Columns, Grid, Item, Items
 from pglet.html import Html
 from pglet.icon import Icon
 from pglet.iframe import IFrame
+from pglet.image import Image
+from pglet.linechart import LineChart
 from pglet.link import Link
-from pglet.toggle import Toggle
 from pglet.message import Message, MessageButton
-from pglet.choicegroup import ChoiceGroup
 from pglet.nav import Nav
+from pglet.page import Page
+from pglet.panel import Panel
+from pglet.piechart import PieChart
+from pglet.progress import Progress
 from pglet.searchbox import SearchBox
 from pglet.slider import Slider
 from pglet.spinbutton import SpinButton
 from pglet.spinner import Spinner
-from pglet.tabs import Tabs, Tab
-from pglet.dialog import Dialog
-from pglet.grid import Grid, Columns, Items, Column, Item
-from pglet.panel import Panel
+from pglet.stack import Stack
+from pglet.tabs import Tab, Tabs
+from pglet.text import Text
+from pglet.textbox import Textbox
+from pglet.toggle import Toggle
 from pglet.toolbar import Toolbar
 from pglet.verticalbarchart import VerticalBarChart
-from pglet.barchart import BarChart
-from pglet.callout import Callout
-from pglet.image import Image
-from pglet.linechart import LineChart
-from pglet.piechart import PieChart
-from pglet.datepicker import DatePicker
 from pglet.pglet import *
-from pglet.reconnecting_websocket import *
\ No newline at end of file
+from pglet.reconnecting_websocket import *
