@@ -1,11 +1,242 @@
+from __future__ import annotations
+
+from typing import Literal, Optional
+
+from beartype import beartype
 from pglet.control import Control
 
-# Column
+SELECTION_MODE = Literal[None, "single", "multiple"]
+SORTABLE = Literal[None, "string", "number", False]
+SORTED = Literal[None, False, "asc", "desc"]
+
+
+class Grid(Control):
+    def __init__(
+        self,
+        id=None,
+        selection_mode: SELECTION_MODE = None,
+        compact=None,
+        header_visible=None,
+        shimmer_lines=None,
+        preserve_selection=None,
+        columns=None,
+        items=None,
+        on_select=None,
+        onitem_invoke=None,
+        width=None,
+        height=None,
+        padding=None,
+        margin=None,
+        visible=None,
+        disabled=None,
+    ):
+        Control.__init__(
+            self,
+            id=id,
+            width=width,
+            height=height,
+            padding=padding,
+            margin=margin,
+            visible=visible,
+            disabled=disabled,
+        )
+
+        self.selection_mode = selection_mode
+        self.compact = compact
+        self.header_visible = header_visible
+        self.shimmer_lines = shimmer_lines
+        self.preserve_selection = preserve_selection
+        self._on_select_handler = None
+        self.on_select = on_select
+        self.onitem_invoke = onitem_invoke
+        self._columns = Columns(columns=columns)
+        self._items = Items(items=items)
+        self._selected_items = []
+
+    def _get_control_name(self):
+        return "grid"
+
+    # columns
+    @property
+    def columns(self):
+        return self._columns.columns
+
+    @columns.setter
+    def columns(self, value):
+        self._columns.columns = value
+
+    # items
+    @property
+    def items(self):
+        return self._items.items
+
+    @items.setter
+    def items(self, value):
+        self._items.items = value
+
+    # on_select
+    @property
+    def on_select(self):
+        return self._on_select_handler
+
+    @on_select.setter
+    def on_select(self, handler):
+        self._on_select_handler = handler
+        self._add_event_handler("select", self._on_select_internal)
+
+    # selected_items
+    @property
+    def selected_items(self):
+        return self._selected_items
+
+    @selected_items.setter
+    def selected_items(self, value):
+        self._selected_items = value
+        indices = [
+            str(idx)
+            for selected_item in value
+            for idx, item in enumerate(self._items.items)
+            if item == selected_item
+        ]
+        self._set_attr("selectedindices", " ".join(indices))
+
+    # onitem_invoke
+    @property
+    def onitem_invoke(self):
+        return self._get_event_handler("itemInvoke")
+
+    @onitem_invoke.setter
+    def onitem_invoke(self, handler):
+        self._add_event_handler("itemInvoke", handler)
+
+    # selection_mode
+    @property
+    def selection_mode(self):
+        return self._get_attr("selection")
+
+    @selection_mode.setter
+    @beartype
+    def selection_mode(self, value: SELECTION_MODE):
+        self._set_attr("selection", value)
+
+    # compact
+    @property
+    def compact(self):
+        return self._get_attr("compact")
+
+    @compact.setter
+    @beartype
+    def compact(self, value: Optional[bool]):
+        self._set_attr("compact", value)
+
+    # header_visible
+    @property
+    def header_visible(self):
+        return self._get_attr("headerVisible")
+
+    @header_visible.setter
+    @beartype
+    def header_visible(self, value: Optional[bool]):
+        self._set_attr("headerVisible", value)
+
+    # preserve_selection
+    @property
+    def preserve_selection(self):
+        return self._get_attr("preserveSelection")
+
+    @preserve_selection.setter
+    @beartype
+    def preserve_selection(self, value: Optional[bool]):
+        self._set_attr("preserveSelection", value)
+
+    # shimmer_lines
+    @property
+    def shimmer_lines(self):
+        return self._get_attr("shimmerLines")
+
+    @shimmer_lines.setter
+    @beartype
+    def shimmer_lines(self, value: Optional[int]):
+        self._set_attr("shimmerLines", value)
+
+    def _on_select_internal(self, e):
+        self._selected_items = [self.page.get_control(id).obj for id in e.data.split()]
+
+        if self._on_select_handler != None:
+            self._on_select_handler(e)
+
+    def _get_children(self):
+        return [self._columns, self._items]
+
+
+class Columns(Control):
+    def __init__(self, id=None, columns=None):
+        Control.__init__(self, id=id)
+
+        self.columns = columns
+
+    def _get_control_name(self):
+        return "columns"
+
+    def _get_children(self):
+        return self.columns
+
+
+class Items(Control):
+    def __init__(self, id=None, items=None):
+        Control.__init__(self, id=id)
+
+        self.__map = {}
+        self.__items = []
+        self.items = items
+
+    # items
+    @property
+    def items(self):
+        return self.__items
+
+    @items.setter
+    @beartype
+    def items(self, value: Optional[list]):
+        self.__items = value or []
+
+    def _get_control_name(self):
+        return "items"
+
+    def _get_children(self):
+        items = []
+        for obj in self.__items:
+            key = obj
+            if isinstance(obj, dict):
+                key = tuple(obj.items())
+            item = self.__map.setdefault(key, Item(obj))
+            item._fetch_attrs()
+            items.append(item)
+
+        del_objs = [key for key, item in self.__map.items() if item not in items]
+        for key in del_objs:
+            del self.__map[key]
+
+        return items
+
+
 class Column(Control):
-    def __init__(self, id=None, name=None, icon=None, icon_only=None, 
-        field_name=None, sortable=None, sort_field=None, sorted=None, resizable=None,
-        min_width=None, max_width=None, on_click=None, template_controls=None,
-        new_window=None, expanded=None):
+    def __init__(
+        self,
+        id=None,
+        name=None,
+        icon=None,
+        icon_only=None,
+        field_name=None,
+        sortable: SORTABLE = None,
+        sort_field=None,
+        sorted: SORTED = None,
+        resizable=None,
+        min_width=None,
+        max_width=None,
+        on_click=None,
+        template_controls=None,
+    ):
         Control.__init__(self, id=id)
 
         self.name = name
@@ -20,22 +251,10 @@ class Column(Control):
         self.max_width = max_width
         self.on_click = on_click
 
-        self.__template_controls = []
-        if template_controls != None:
-            for control in template_controls:
-                self.__template_controls.append(control)
+        self.template_controls = template_controls or []
 
     def _get_control_name(self):
         return "column"
-    
-    # template_controls
-    @property
-    def template_controls(self):
-        return self.__template_controls
-
-    @template_controls.setter
-    def template_controls(self, value):
-        self.__template_controls = value
 
     # name
     @property
@@ -61,8 +280,8 @@ class Column(Control):
         return self._get_attr("iconOnly")
 
     @icon_only.setter
-    def icon_only(self, value):
-        assert value == None or isinstance(value, bool), "iconOnly must be a boolean"
+    @beartype
+    def icon_only(self, value: Optional[bool]):
         self._set_attr("iconOnly", value)
 
     # field_name
@@ -80,7 +299,8 @@ class Column(Control):
         return self._get_attr("sortable")
 
     @sortable.setter
-    def sortable(self, value):
+    @beartype
+    def sortable(self, value: SORTABLE):
         self._set_attr("sortable", value)
 
     # sort_field
@@ -98,7 +318,8 @@ class Column(Control):
         return self._get_attr("sorted")
 
     @sorted.setter
-    def sorted(self, value):
+    @beartype
+    def sorted(self, value: SORTED):
         self._set_attr("sorted", value)
 
     # resizable
@@ -107,8 +328,8 @@ class Column(Control):
         return self._get_attr("resizable")
 
     @resizable.setter
-    def resizable(self, value):
-        assert value == None or isinstance(value, bool), "resizable must be a boolean"
+    @beartype
+    def resizable(self, value: Optional[bool]):
         self._set_attr("resizable", value)
 
     # min_width
@@ -117,19 +338,20 @@ class Column(Control):
         return self._get_attr("minWidth")
 
     @min_width.setter
-    def min_width(self, value):
-        assert value == None or isinstance(value, int), "minWidth must be an int"
+    @beartype
+    def min_width(self, value: Optional[int]):
         self._set_attr("minWidth", value)
-    
-    
+
     # max_width
     @property
     def max_width(self):
         return self._get_attr("maxWidth")
 
     @max_width.setter
-    def max_width(self, value):
-        assert value == None or isinstance(value, int), "maxWidth must be an int"
+    @beartype
+    def max_width(
+        self, value: Optional[int]
+    ):  # could these not be floats? Union[None, int, float]
         self._set_attr("maxWidth", value)
 
     # on_click
@@ -138,46 +360,45 @@ class Column(Control):
         return self._get_attr("on_click")
 
     @on_click.setter
-    def on_click(self, value):
-        assert value == None or isinstance(value, bool), "resizable must be a boolean"
+    def on_click(self, value):  # beartype currently has an issue with typing.Callable
         self._set_attr("on_click", value)
 
     def _get_children(self):
-        return self.__template_controls
+        return self.template_controls
+
 
-# Item
 class Item(Control):
     def __init__(self, obj):
         Control.__init__(self)
-        assert obj != None, "Obj cannot be empty"
-        self.__obj = obj
-
-    @property
-    def obj(self):
-        return self.__obj
+        assert obj, "obj cannot be empty"
+        self.obj = obj
 
     def _set_attr(self, name, value, dirty=True):
 
-        if value == None:
+        if value is None:
             return
 
         orig_val = self._get_attr(name)
-        if orig_val != None and isinstance(orig_val, bool):
-            value = str(value).lower() == "true"
-        elif orig_val != None and isinstance(orig_val, float):
-            value = float(str(value))
+        if orig_val is not None:
+            if isinstance(orig_val, bool):
+                value = str(value).lower() == "true"
+            elif isinstance(orig_val, float):
+                value = float(str(value))
 
         self._set_attr_internal(name, value, dirty=False)
-        setattr(self.__obj, name, value)
+        if isinstance(self.obj, dict):
+            self.obj[name] = value
+        else:
+            setattr(self.obj, name, value)
 
     def _fetch_attrs(self):
         # reflection
-        for name, val in vars(self.__obj).items():
-            data_type = "string"
-            if isinstance(val, bool):
-                data_type = "bool"
-            elif isinstance(val, float):
-                data_type = "float"
+        obj = self.obj if isinstance(self.obj, dict) else vars(self.obj)
+
+        for name, val in obj.items():
+            data_type = (
+                type(val).__name__ if isinstance(val, (bool, float)) else "string"
+            )
             orig_val = self._get_attr(name, data_type=data_type)
 
             if val != orig_val:
@@ -185,219 +406,3 @@ class Item(Control):
 
     def _get_control_name(self):
         return "item"
-
-# Columns
-class Columns(Control):
-    def __init__(self, id=None, columns=None):
-        Control.__init__(self, id=id)
-    
-        self.__columns = []
-        if columns != None:
-            for column in columns:
-                self.__columns.append(column)
-
-    # columns
-    @property
-    def columns(self):
-        return self.__columns
-
-    @columns.setter
-    def columns(self, value):
-        self.__columns = value
-
-    def _get_control_name(self):
-        return "columns"
-
-    def _get_children(self):
-        return self.__columns
-
-# Items
-class Items(Control):
-    def __init__(self, id=None, items=None):
-        Control.__init__(self, id=None)
-    
-        self.__map = {}
-        self.__items = []
-        if items != None:
-            for item in items:
-                self.__items.append(item)
-
-    # items
-    @property
-    def items(self):
-        return self.__items
-
-    @items.setter
-    def items(self, value):
-        self.__items = value
-
-    def _get_control_name(self):
-        return "items"
-
-    def _get_children(self):
-        items = []
-        if self.__items and len(self.__items) > 0:
-            for obj in self.__items:
-                item = self.__map.get(obj)
-                if item == None:
-                    item = Item(obj)
-                    self.__map[obj] = item
-                item._fetch_attrs()
-                items.append(item)
-        
-        del_objs = []
-        for obj, item in self.__map.items():
-            if item not in items:
-                del_objs.append(obj)
-
-        for obj in del_objs:
-            del self.__map[obj]
-                
-        return items
-
-class Grid(Control):
-    def __init__(self, id=None, selection_mode=None, compact=None, header_visible=None, shimmer_lines=None,
-            preserve_selection=None,
-            columns=None, items=None, on_select=None, onitem_invoke=None,
-            width=None, height=None, padding=None, margin=None, visible=None, disabled=None):
-        
-        Control.__init__(self, id=id,
-            width=width, height=height, padding=padding, margin=margin,
-            visible=visible, disabled=disabled)
-        
-        self.selection_mode = selection_mode
-        self.compact = compact
-        self.header_visible = header_visible
-        self.shimmer_lines = shimmer_lines
-        self.preserve_selection = preserve_selection
-        self._on_select_handler = None
-        self.on_select = on_select
-        self.onitem_invoke = onitem_invoke
-        self._columns = Columns(columns=columns)
-        self._items = Items(items=items)
-        self._selected_items = []
-        
-    def _get_control_name(self):
-        return "grid"
-
-    # columns
-    @property
-    def columns(self):
-        return self._columns.columns
-
-    @columns.setter
-    def columns(self, value):
-        self._columns.columns = value
-
-    # items
-    @property
-    def items(self):
-        return self._items.items
-
-    @items.setter
-    def items(self, value):
-        self._items.items = value
-    
-    # on_select
-    @property
-    def on_select(self):
-        return self._on_select_handler
-
-    @on_select.setter
-    def on_select(self, handler):
-        self._on_select_handler = handler
-        if handler != None:
-            self._add_event_handler("select", self._on_select_internal)
-        else:
-            self._add_event_handler("select", None)
-
-    # selected_items
-    @property
-    def selected_items(self):
-        return self._selected_items
-
-    @selected_items.setter
-    def selected_items(self, value):
-        self._selected_items = value
-        indices = []
-        for selected_item in value:
-            idx = 0
-            for item in self._items.items:
-                if item == selected_item:
-                   indices.append(str(idx))
-                idx += 1
-        self._set_attr("selectedindices", ' '.join(indices))  
-
-    # onitem_invoke
-    @property
-    def onitem_invoke(self):
-        return self._get_event_handler("itemInvoke")
-
-    @onitem_invoke.setter
-    def onitem_invoke(self, handler):
-        self._add_event_handler("itemInvoke", handler)
-
-    # selection_mode
-    @property
-    def selection_mode(self):
-        return self._get_attr("selection")
-
-    @selection_mode.setter
-    def selection_mode(self, value):
-        self._set_attr("selection", value)
-
-    # compact
-    @property
-    def compact(self):
-        return self._get_attr("compact")
-
-    @compact.setter
-    def compact(self, value):
-        assert value == None or isinstance(value, bool), "compact must be a boolean"
-        self._set_attr("compact", value)
-
-    # header_visible
-    @property
-    def header_visible(self):
-        return self._get_attr("headerVisible")
-
-    @header_visible.setter
-    def header_visible(self, value):
-        assert value == None or isinstance(value, bool), "header_visible must be a boolean"
-        self._set_attr("headerVisible", value)
-
-    # preserve_selection
-    @property
-    def preserve_selection(self):
-        return self._get_attr("preserveSelection")
-
-    @preserve_selection.setter
-    def preserve_selection(self, value):
-        assert value == None or isinstance(value, bool), "preserve_selection must be a boolean"
-        self._set_attr("preserveSelection", value)
-
-    # shimmer_lines
-    @property
-    def shimmer_lines(self):
-        return self._get_attr("shimmerLines")
-
-    @shimmer_lines.setter
-    def shimmer_lines(self, value):
-        assert value == None or isinstance(value, int), "shimmerLines must be an int"
-        self._set_attr("shimmerLines", value)
-
-    def _on_select_internal(self, e):
-
-        self._selected_items = []
-        for id in e.data.split(' '):
-            if id != "":
-                self._selected_items.append(self.page.get_control(id).obj)
-
-        if self._on_select_handler != None:
-            self._on_select_handler(e)
-
-    def _get_children(self):
-        result=[]
-        result.append(self._columns)
-        result.append(self._items)
-        return result
\ No newline at end of file
