@@ -1,22 +1,38 @@
+import json
 import logging
-from typing import List
-from pglet.protocol import Command
+import threading
+from typing import List, Literal, Optional
+from beartype import beartype
+
+from pglet import constants
 from pglet.connection import Connection
 from pglet.control import Control
 from pglet.control_event import ControlEvent
-from pglet import constants
-import json
-import threading
+from pglet.protocol import Command
+
+ALIGN = Literal[
+    None,
+    "start",
+    "end",
+    "center",
+    "space-between",
+    "space-around",
+    "space-evenly",
+    "baseline",
+    "stretch",
+]
+
+THEME = Literal[None, "light", "dark"]
+
 
 class Page(Control):
-
     def __init__(self, conn: Connection, session_id):
         Control.__init__(self, id="page")
-    
+
         self._conn = conn
         self._session_id = session_id
-        self._controls = [] # page controls
-        self._index = {} # index with all page controls
+        self._controls = []  # page controls
+        self._index = {}  # index with all page controls
         self._index[self.id] = self
         self._last_event = None
         self._event_available = threading.Event()
@@ -35,16 +51,20 @@ class Page(Control):
         return self._controls
 
     def _fetch_page_details(self):
-        values = self._conn.send_commands(self._conn.page_name, self._session_id, [
-            Command(0, 'get', ['page', 'hash'], None, None, None),
-            Command(0, 'get', ['page', 'win_width'], None, None, None),
-            Command(0, 'get', ['page', 'win_height'], None, None, None),
-            Command(0, 'get', ['page', 'userid'], None, None, None),
-            Command(0, 'get', ['page', 'userlogin'], None, None, None),
-            Command(0, 'get', ['page', 'username'], None, None, None),
-            Command(0, 'get', ['page', 'useremail'], None, None, None),
-            Command(0, 'get', ['page', 'userclientip'], None, None, None)
-        ]).results
+        values = self._conn.send_commands(
+            self._conn.page_name,
+            self._session_id,
+            [
+                Command(0, "get", ["page", "hash"], None, None, None),
+                Command(0, "get", ["page", "win_width"], None, None, None),
+                Command(0, "get", ["page", "win_height"], None, None, None),
+                Command(0, "get", ["page", "userid"], None, None, None),
+                Command(0, "get", ["page", "userlogin"], None, None, None),
+                Command(0, "get", ["page", "username"], None, None, None),
+                Command(0, "get", ["page", "useremail"], None, None, None),
+                Command(0, "get", ["page", "userclientip"], None, None, None),
+            ],
+        ).results
         self._set_attr("hash", values[0], False)
         self._set_attr("win_width", values[1], False)
         self._set_attr("win_height", values[2], False)
@@ -68,17 +88,19 @@ class Page(Control):
         # build commands
         for control in controls:
             control.build_update_commands(self._index, added_controls, commands)
-        
+
         if len(commands) == 0:
             return
 
         # execute commands
-        results = self._conn.send_commands(self._conn.page_name, self._session_id, commands).results
+        results = self._conn.send_commands(
+            self._conn.page_name, self._session_id, commands
+        ).results
 
         if len(results) > 0:
             n = 0
             for line in results:
-                for id in line.split(' '):
+                for id in line.split(" "):
                     added_controls[n]._Control__uid = id
                     added_controls[n].page = self
 
@@ -132,13 +154,19 @@ class Page(Control):
                     if id in self._index:
                         for name in props:
                             if name != "i":
-                                self._index[id]._set_attr(name, props[name], dirty=False)
-        
+                                self._index[id]._set_attr(
+                                    name, props[name], dirty=False
+                                )
+
         elif e.target in self._index:
-            self._last_event = ControlEvent(e.target, e.name, e.data, self._index[e.target], self)
+            self._last_event = ControlEvent(
+                e.target, e.name, e.data, self._index[e.target], self
+            )
             handler = self._index[e.target].event_handlers.get(e.name)
             if handler:
-                t = threading.Thread(target=handler, args=(self._last_event,), daemon=True)
+                t = threading.Thread(
+                    target=handler, args=(self._last_event,), daemon=True
+                )
                 t.start()
             self._event_available.set()
 
@@ -160,46 +188,52 @@ class Page(Control):
                 return True
             elif e.control == self and e.name.lower() == "dismisssignin":
                 return False
-    
+
     def signout(self):
         return self._send_command("signout", None)
 
     def can_access(self, users_and_groups):
-        return self._send_command("canAccess", [users_and_groups]).result.lower() == "true"
-    
+        return (
+            self._send_command("canAccess", [users_and_groups]).result.lower() == "true"
+        )
+
     def close(self):
         if self._session_id == constants.ZERO_SESSION:
             self._conn.close()
-        
-    def _send_command(self, name: str, values: List[str]):
-        return self._conn.send_command(self._conn.page_name, self._session_id, Command(0, name, values, None, None, None))      
 
-# url
+    def _send_command(self, name: str, values: List[str]):
+        return self._conn.send_command(
+            self._conn.page_name,
+            self._session_id,
+            Command(0, name, values, None, None, None),
+        )
+
+    # url
     @property
     def url(self):
         return self._conn.page_url
 
-# name
+    # name
     @property
     def name(self):
         return self._conn.page_name
 
-# connection
+    # connection
     @property
     def connection(self):
         return self._conn
 
-# index
+    # index
     @property
     def index(self):
         return self._index
 
-# session_id
+    # session_id
     @property
     def session_id(self):
         return self._session_id
 
-# controls
+    # controls
     @property
     def controls(self):
         return self._controls
@@ -208,7 +242,7 @@ class Page(Control):
     def controls(self, value):
         self._controls = value
 
-# title
+    # title
     @property
     def title(self):
         return self._get_attr("title")
@@ -217,53 +251,56 @@ class Page(Control):
     def title(self, value):
         self._set_attr("title", value)
 
-# vertical_fill
+    # vertical_fill
     @property
     def vertical_fill(self):
         return self._get_attr("verticalFill")
 
     @vertical_fill.setter
-    def vertical_fill(self, value):
-        assert value == None or isinstance(value, bool), "verticalFill must be a bool"
+    @beartype
+    def vertical_fill(self, value: Optional[bool]):
         self._set_attr("verticalFill", value)
 
-# horizontal_align
+    # horizontal_align
     @property
     def horizontal_align(self):
         return self._get_attr("horizontalAlign")
 
     @horizontal_align.setter
-    def horizontal_align(self, value):
+    @beartype
+    def horizontal_align(self, value: ALIGN):
         self._set_attr("horizontalAlign", value)
 
-# vertical_align
+    # vertical_align
     @property
     def vertical_align(self):
         return self._get_attr("verticalAlign")
 
     @vertical_align.setter
-    def vertical_align(self, value):
+    @beartype
+    def vertical_align(self, value: ALIGN):
         self._set_attr("verticalAlign", value)
 
-# gap
+    # gap
     @property
     def gap(self):
         return self._get_attr("gap")
 
     @gap.setter
-    def gap(self, value):
+    @beartype
+    def gap(self, value: Optional[int]):
         self._set_attr("gap", value)
 
-# padding
+    # padding
     @property
     def padding(self):
         return self._get_attr("padding")
 
     @padding.setter
     def padding(self, value):
-        self._set_attr("padding", value)       
+        self._set_attr("padding", value)
 
-# bgcolor
+    # bgcolor
     @property
     def bgcolor(self):
         return self._get_attr("bgcolor")
@@ -272,16 +309,17 @@ class Page(Control):
     def bgcolor(self, value):
         self._set_attr("bgcolor", value)
 
-# theme
+    # theme
     @property
     def theme(self):
         return self._get_attr("theme")
 
     @theme.setter
-    def theme(self, value):
+    @beartype
+    def theme(self, value: THEME):
         self._set_attr("theme", value)
 
-# theme_primary_color
+    # theme_primary_color
     @property
     def theme_primary_color(self):
         return self._get_attr("themePrimaryColor")
@@ -290,7 +328,7 @@ class Page(Control):
     def theme_primary_color(self, value):
         self._set_attr("themePrimaryColor", value)
 
-# theme_text_color
+    # theme_text_color
     @property
     def theme_text_color(self):
         return self._get_attr("themeTextColor")
@@ -299,7 +337,7 @@ class Page(Control):
     def theme_text_color(self, value):
         self._set_attr("themeTextColor", value)
 
-# theme_background_color
+    # theme_background_color
     @property
     def theme_background_color(self):
         return self._get_attr("themeBackgroundColor")
@@ -308,7 +346,7 @@ class Page(Control):
     def theme_background_color(self, value):
         self._set_attr("themeBackgroundColor", value)
 
-# hash
+    # hash
     @property
     def hash(self):
         return self._get_attr("hash")
@@ -317,7 +355,7 @@ class Page(Control):
     def hash(self, value):
         self._set_attr("hash", value)
 
-# win_width
+    # win_width
     @property
     def win_width(self):
         w = self._get_attr("win_width")
@@ -325,7 +363,7 @@ class Page(Control):
             return int(w)
         return 0
 
-# win_height
+    # win_height
     @property
     def win_height(self):
         h = self._get_attr("win_height")
@@ -333,25 +371,27 @@ class Page(Control):
             return int(h)
         return 0
 
-# signin
+    # signin
     @property
     def signin(self):
         return self._get_attr("signin")
 
     @signin.setter
-    def signin(self, value):
+    @beartype
+    def signin(self, value: Optional[bool]):
         self._set_attr("signin", value)
 
-# signin_allow_dismiss
+    # signin_allow_dismiss
     @property
     def signin_allow_dismiss(self):
         return self._get_attr("signinAllowDismiss")
 
     @signin_allow_dismiss.setter
-    def signin_allow_dismiss(self, value):
+    @beartype
+    def signin_allow_dismiss(self, value: Optional[bool]):
         self._set_attr("signinAllowDismiss", value)
 
-# signin_groups
+    # signin_groups
     @property
     def signin_groups(self):
         return self._get_attr("signinGroups")
@@ -360,52 +400,32 @@ class Page(Control):
     def signin_groups(self, value):
         self._set_attr("signinGroups", value)
 
-# user_id
+    # user_id
     @property
     def user_id(self):
         return self._get_attr("userId")
 
-    @user_id.setter
-    def user_id(self, value):
-        self._set_attr("userId", value)        
-
-# user_login
+    # user_login
     @property
     def user_login(self):
         return self._get_attr("userLogin")
 
-    @user_login.setter
-    def user_login(self, value):
-        self._set_attr("userLogin", value)                
-
-# user_name
+    # user_name
     @property
     def user_name(self):
         return self._get_attr("userName")
 
-    @user_name.setter
-    def user_name(self, value):
-        self._set_attr("userName", value)
-
-# user_email
+    # user_email
     @property
     def user_email(self):
         return self._get_attr("userEmail")
 
-    @user_email.setter
-    def user_email(self, value):
-        self._set_attr("userEmail", value)
-
-# user_client_ip
+    # user_client_ip
     @property
     def user_client_ip(self):
         return self._get_attr("userClientIP")
 
-    @user_client_ip.setter
-    def user_client_ip(self, value):
-        self._set_attr("userClientIP", value)
-
-# on_signin
+    # on_signin
     @property
     def on_signin(self):
         return self._get_event_handler("signin")
@@ -414,7 +434,7 @@ class Page(Control):
     def on_signin(self, handler):
         self._add_event_handler("signin", handler)
 
-# on_dismiss_signin
+    # on_dismiss_signin
     @property
     def on_dismiss_signin(self):
         return self._get_event_handler("dismissSignin")
@@ -423,16 +443,16 @@ class Page(Control):
     def on_dismiss_signin(self, handler):
         self._add_event_handler("dismissSignin", handler)
 
-# on_signout
+    # on_signout
     @property
     def on_signout(self):
         return self._get_event_handler("signout")
 
     @on_signout.setter
     def on_signout(self, handler):
-        self._add_event_handler("signout", handler)        
+        self._add_event_handler("signout", handler)
 
-# on_close
+    # on_close
     @property
     def on_close(self):
         return self._get_event_handler("close")
@@ -441,7 +461,7 @@ class Page(Control):
     def on_close(self, handler):
         self._add_event_handler("close", handler)
 
-# on_hash_change
+    # on_hash_change
     @property
     def on_hash_change(self):
         return self._get_event_handler("hashChange")
@@ -450,11 +470,11 @@ class Page(Control):
     def on_hash_change(self, handler):
         self._add_event_handler("hashChange", handler)
 
-# on_resize
+    # on_resize
     @property
     def on_resize(self):
         return self._get_event_handler("resize")
 
     @on_resize.setter
     def on_resize(self, handler):
-        self._add_event_handler("resize", handler)
\ No newline at end of file
+        self._add_event_handler("resize", handler)
