@@ -1,15 +1,49 @@
+from typing import Optional, Literal
+from beartype import beartype
 from pglet.control import Control
 
+ALIGN = Literal[None, "left", "right", "center", "justify"]
+
+
 class Textbox(Control):
-    def __init__(self, label=None, id=None, value=None, placeholder=None,
-            error_message=None, description=None, icon=None, icon_color=None, prefix=None, suffix=None,
-            multiline=None, password=None, required=None, read_only=None, auto_adjust_height=None, underlined=None, borderless=None,
-            on_change=None,
-            width=None, height=None, padding=None, margin=None, align=None,
-            visible=None, disabled=None):
-        Control.__init__(self, id=id,
-            width=width, height=height, padding=padding, margin=margin,
-            visible=visible, disabled=disabled)
+    def __init__(
+        self,
+        label=None,
+        id=None,
+        value=None,
+        placeholder=None,
+        error_message=None,
+        description=None,
+        icon=None,
+        icon_color=None,
+        prefix=None,
+        suffix=None,
+        multiline=None,
+        password=None,
+        required=None,
+        read_only=None,
+        auto_adjust_height=None,
+        underlined=None,
+        borderless=None,
+        on_change=None,
+        width=None,
+        height=None,
+        padding=None,
+        margin=None,
+        align: ALIGN = None,
+        visible=None,
+        disabled=None,
+    ):
+        Control.__init__(
+            self,
+            id=id,
+            width=width,
+            height=height,
+            padding=padding,
+            margin=margin,
+            visible=visible,
+            disabled=disabled,
+        )
         self.label = label
         self.value = value
         self.placeholder = placeholder
@@ -32,7 +66,7 @@ class Textbox(Control):
     def _get_control_name(self):
         return "textbox"
 
-# label
+    # label
     @property
     def label(self):
         return self._get_attr("label")
@@ -41,7 +75,7 @@ class Textbox(Control):
     def label(self, value):
         self._set_attr("label", value)
 
-# value
+    # value
     @property
     def value(self):
         return self._get_attr("value")
@@ -50,7 +84,7 @@ class Textbox(Control):
     def value(self, value):
         self._set_attr("value", value)
 
-# placeholder
+    # placeholder
     @property
     def placeholder(self):
         return self._get_attr("placeholder")
@@ -59,7 +93,7 @@ class Textbox(Control):
     def placeholder(self, value):
         self._set_attr("placeholder", value)
 
-# error_message
+    # error_message
     @property
     def error_message(self):
         return self._get_attr("errorMessage")
@@ -68,7 +102,7 @@ class Textbox(Control):
     def error_message(self, value):
         self._set_attr("errorMessage", value)
 
-# description
+    # description
     @property
     def description(self):
         return self._get_attr("description")
@@ -77,7 +111,7 @@ class Textbox(Control):
     def description(self, value):
         self._set_attr("description", value)
 
-# icon
+    # icon
     @property
     def icon(self):
         return self._get_attr("icon")
@@ -86,7 +120,7 @@ class Textbox(Control):
     def icon(self, value):
         self._set_attr("icon", value)
 
-# icon_color
+    # icon_color
     @property
     def icon_color(self):
         return self._get_attr("iconColor")
@@ -95,7 +129,7 @@ class Textbox(Control):
     def icon_color(self, value):
         self._set_attr("iconColor", value)
 
-# prefix
+    # prefix
     @property
     def prefix(self):
         return self._get_attr("prefix")
@@ -104,95 +138,96 @@ class Textbox(Control):
     def prefix(self, value):
         self._set_attr("prefix", value)
 
-# suffix
+    # suffix
     @property
     def suffix(self):
         return self._get_attr("suffix")
 
     @suffix.setter
     def suffix(self, value):
-        self._set_attr("suffix", value)        
+        self._set_attr("suffix", value)
 
-# align
+    # align
     @property
     def align(self):
         return self._get_attr("align")
 
     @align.setter
-    def align(self, value):
+    @beartype
+    def align(self, value: ALIGN):
         self._set_attr("align", value)
 
-# multiline
+    # multiline
     @property
     def multiline(self):
         return self._get_attr("multiline")
 
     @multiline.setter
-    def multiline(self, value):
-        assert value == None or isinstance(value, bool), "multiline must be a boolean"
+    @beartype
+    def multiline(self, value: Optional[bool]):
         self._set_attr("multiline", value)
 
-# read_only
+    # read_only
     @property
     def read_only(self):
         return self._get_attr("readOnly")
 
     @read_only.setter
-    def read_only(self, value):
-        assert value == None or isinstance(value, bool), "read_only must be a boolean"
+    @beartype
+    def read_only(self, value: Optional[bool]):
         self._set_attr("readOnly", value)
 
-# auto_adjust_height
+    # auto_adjust_height
     @property
     def auto_adjust_height(self):
         return self._get_attr("autoadjustheight")
 
     @auto_adjust_height.setter
-    def auto_adjust_height(self, value):
-        assert value == None or isinstance(value, bool), "auto_adjust_height must be a boolean"
+    @beartype
+    def auto_adjust_height(self, value: Optional[bool]):
         self._set_attr("autoadjustheight", value)
 
-# underlined
+    # underlined
     @property
     def underlined(self):
         return self._get_attr("underlined")
 
     @underlined.setter
-    def underlined(self, value):
-        assert value == None or isinstance(value, bool), "underlined must be a boolean"
+    @beartype
+    def underlined(self, value: Optional[bool]):
         self._set_attr("underlined", value)
 
-# borderless
+    # borderless
     @property
     def borderless(self):
         return self._get_attr("borderless")
 
     @borderless.setter
-    def borderless(self, value):
-        assert value == None or isinstance(value, bool), "borderless must be a boolean"
-        self._set_attr("borderless", value)                                
+    @beartype
+    def borderless(self, value: Optional[bool]):
+        self._set_attr("borderless", value)
 
-# password
+    # password
     @property
     def password(self):
         return self._get_attr("password")
 
     @password.setter
-    def password(self, value):
-        assert value == None or isinstance(value, bool), "password must be a boolean"
+    @beartype
+    def password(self, value: Optional[bool]):
         self._set_attr("password", value)
 
-# required
+    # required
     @property
     def required(self):
         return self._get_attr("required")
 
     @required.setter
-    def required(self, value):
-        assert value == None or isinstance(value, bool), "required must be a boolean"
+    @beartype
+    def required(self, value: Optional[bool]):
         self._set_attr("required", value)
 
-# on_change
+    # on_change
     @property
     def on_change(self):
         return self._get_event_handler("change")
@@ -203,4 +238,4 @@ class Textbox(Control):
         if handler != None:
             self._set_attr("onchange", True)
         else:
-            self._set_attr("onchange", None)
\ No newline at end of file
+            self._set_attr("onchange", None)
