@@ -1,11 +1,20 @@
 import pglet
-from pglet import Callout, Text, Button
+from pglet import Callout, Text
+
 
 def test_callout_add():
-    c = Callout(target='button1', position='leftBottom', gap=100, beak=True, beak_width=10, page_padding=10,
-    focus=False, cover=True, visible=True, controls=[
-        Text(value='This is callout')
-        ])
+    c = Callout(
+        target="button1",
+        position="leftBottom",
+        gap=100,
+        beak=True,
+        beak_width=10,
+        page_padding=10,
+        focus=False,
+        cover=True,
+        visible=True,
+        controls=[Text(value="This is callout")],
+    )
 
     assert isinstance(c, pglet.Control)
     assert isinstance(c, pglet.Callout)
@@ -13,4 +22,4 @@ def test_callout_add():
         'callout beak="true" beakwidth="10" cover="true" focus="false" gap="100" pagepadding="10" '
         'position="leftBottom" target="button1" visible="true"\n'
         '  text value="This is callout"'
-    ), "Test failed"
\ No newline at end of file
+    ), "Test failed"
